@@ -168,7 +168,7 @@ class EventFramework(_EventFramework):
         """
         return self.equeue.push(event, timeout)
 
-    def config(self, step: int | None = _PARAM_NONE, timeout: int | None = _PARAM_NONE, log_path: str = _PARAM_NONE,
+    def config(self, step: int = _PARAM_NONE, timeout: int = _PARAM_NONE, log_path: str = _PARAM_NONE,
                log_immediate: bool = _PARAM_NONE, log_format: str = _PARAM_NONE, log_level: int = _PARAM_NONE):
         """
         配置事件框架
@@ -208,7 +208,7 @@ class EventFramework(_EventFramework):
             self.log_level = log_level
             self._initlogger()
 
-    def assign(self, worker: Worker|None, station: EventStation) -> bool:
+    def assign(self, worker: Worker, station: EventStation) -> bool:
         """
         布置任务到worker
         assign task to worker
